% 2-D gaussian blob of unit peak magnitude and unit std dev.
%
% Nick Kingsbury, Cambridge University, 2006.

pos1 = [0.06 0.3 0.4 0.4]; % Use subplot so text is a reasonable size.

% pdf of 2-D Normal distr with mean 0 and variance 1.
sig = sqrt(1);
xmin = -4;
xmax = 4;
dx = 1/4;
x = [xmin:dx:xmax]';
y = exp(-x.^2/(2*sig.^2));
yy = y * y.';
setfig(1)
subplot('position',pos1);
surf(x,x,yy)
% shading flat; colormap(hot)
shading faceted
colormap(cool)
axis([xmin xmax xmin xmax 0 1])
xlabel('s','FontSize',12);
ylabel('t','FontSize',12);

figure(1)
print -depsc 'gaussblob'

setfig(2)
subplot('position',pos1);
yy2 = yy/(2*pi);
surf(x,x,yy2)
% shading flat; colormap(hot)
shading faceted
cmap=colormap(cool);
axis([xmin xmax xmin xmax 0 0.2])
xlabel('x','FontSize',12);
ylabel('y','FontSize',12);

figure(2)
print -depsc 'gaussfilt'

setfig(3)
subplot('position',pos1);
clev = [0.2 1:3]'*0.05;
[cm,hc] = contour(x,x,yy2,clev);
set(hc,'Linewidth',2);
% shading flat; colormap(hot)
axis([xmin xmax xmin xmax])
axis square
grid on
xlabel('x','FontSize',12);
ylabel('y','FontSize',12);
for k = 1:length(clev),
    set(hc(k),'EdgeColor',cmap(round(clev(k)*64/max(yy2(:))),:));
    maxy = max(get(hc(k),'Ydata'));
    text(0,maxy,sprintf('%.2f',clev(k)),'Fontsize',10,...
        'horiz','c','vert','bot');
end
figure(3)
print -depsc 'gausscontour'


% Now do 1-D Gaussian pulse and its spectrum.
xmin = -32;
xmax = 32;
dx = 1/32;
x = [xmin:dx:xmax-dx]';
b = [0.5 1 2 4];
y = [];
Y = [];
for k = 1:length(b),
    y(:,k) = exp(-x.^2/(2*b(k).^2)) / (b(k)*sqrt(2*pi));
    Y(:,k) = fftshift(fft(y(:,k)*dx));
end


setfig(4)
subplot('position',pos1);
yh = plot(x,y,'Linewidth',2);
axis([-8 8 -0.2 1]);
set(gca,'Xtick',[-8:2:8]);
grid on;
text(-0.4,0.7,'b = 0.5','vert','m','horiz','r');
text(1.2,0.3,'b = 1','vert','m','horiz','l');
text(-2,0.12,'b = 2','vert','bot','horiz','r');
text(4.1,0.06,'b = 4','vert','bot','horiz','l');

print -depsc 'gauss1D'

setfig(5)
subplot('position',pos1);
omega = x*2*pi/((xmax-xmin)*dx);
Yh = plot(omega,abs(Y),'Linewidth',2);
axis([-4 4 -0.2 1.2]);
set(gca,'Xtick',[-4:4]);
grid on;
text(-2,0.7,'b = 0.5','vert','m','horiz','r');
text(-1.3,0.5,'1','vert','m','horiz','r');
text(-0.9,0.3,'2','vert','m','horiz','r');
text(-0.65,0.1,'4','vert','m','horiz','r');

print -depsc 'gaussfreq'



