% ph_colourshift.m
% Routine called by 'Colour shift' menu item in photo editor.
%
% Nick Kingsbury, Cambridge University, March 2006.

switch mode
    
    case 'Init'  
        % Set up figure window for Colour Shift commands
        figure(2);
        set(gcf,'position',[fig2pos  420  100]);
        set(gcf,'numbertitle','off','name','Colour Shift');
        
        % Initialise colour correction gains and cmode, if they have not
        % been used already.  cmode = 0 for RGB, 1 for YUV, 2 for HSV.
        if exist('cgain') ~= 1, cgain = [1 1 1]'; end
        if exist('cofst') ~= 1, cofst = [0 0 0]'; end
        if exist('cmode') ~= 1, cmode = 0; end 
        
        % Buttons for colour selection.
        labelrgb = {'Red:','Green:','Blue:'};
        labelyuv = {'Y (lum):','U (B-Y):','V (R-Y):'};
        labelhsv = {'Hue:','Sat.:','Value:'};
        for k = 1:3,
            slide(k) = uicontrol(gcf,'style','slider','sliderstep',[1 10]/100,...
              'pos',[50 70-20*k 100 20],'call','mode=''Slider''; ph_colourshift');
            lab(k) = uicontrol(gcf,'style','text','pos',[10 70-20*k 40 20]);
            edbox(k) = uicontrol(gcf,'style','edit','pos',[150 70-20*k 40 20],...
              'call','mode=''Edit box''; ph_colourshift');
            slide(k+3) = uicontrol(gcf,'style','slider','sliderstep',[1 10]/100,...
              'pos',[200 70-20*k 100 20],'call','mode=''Slider''; ph_colourshift');
            edbox(k+3) = uicontrol(gcf,'style','edit','pos',[300 70-20*k 40 20],...
              'call','mode=''Edit box''; ph_colourshift');
        end
        uicontrol(gcf,'style','text','str','Adjust Colour Gain',...
            'pos',[60 70 120 16]);
        uicontrol(gcf,'style','text','str','Adjust Colour Offset',...
            'pos',[210 70 120 16]);
        
        % Other buttons: reset, swap and close box.
        resetbal = uicontrol(gcf,'str','Reset','pos',[350 70 60 20],...
            'call','mode=''Reset''; ph_colourshift');
        swap = uicontrol(gcf,'str','YUV/HSV','pos',[350 40 60 20],...
            'call','mode=''Swap''; ph_colourshift');
        closebtn = uicontrol(gcf,'str','Close','pos',[350 10 60 20],...
            'call','mode=''Close''; ph_colourshift');
        
        % If YUV or HSV mode, pre-calculate xyuv or xhsv.
        if cmode == 1,
            xyuv=rgb2yuv(double(xui)/255);
            yyuv = xyuv;
        elseif cmode == 2,
            xhsv=rgb2hsv(double(xui)/255); 
            yhsv = xhsv;
        end
        mode = 'Colour';
        
    case 'Slider'
        for k=1:3,
            cgain(k) = 2*get(slide(k),'value'); 
            cofst(k) = get(slide(k+3),'value') - 0.5; 
        end
        mode = 'Colour';
        
    case 'Edit box'
        for k=1:3, 
            cgain(k) = min(max(sscanf(get(edbox(k),'string'),'%f'),0),2); 
            cofst(k) = min(max(sscanf(get(edbox(k+3),'string'),'%f'),-0.5),0.5); 
        end
        mode = 'Colour';
        
    case 'Reset'
        cgain = [1 1 1]';
        cofst = [0 0 0]';
        mode = 'Colour';
        
    case 'Swap'
        cmode = mod(cmode+1,3);
        if cmode == 1,
            xyuv=rgb2yuv(double(xui)/255);
            yyuv = xyuv;
        elseif cmode == 2,
            xhsv=rgb2hsv(double(xui)/255); 
            yhsv = xhsv;
        end
        cgain = [1 1 1]';
        cofst = [0 0 0]';
        mode = 'Colour';
        
    case 'Close'
        close(2); 
        newbefore = 1; 
        showimages;
        
end

    
switch mode
    
    case 'Colour'
        for k=1:3,
            set(slide(k),'value',0.5*cgain(k)); 
            set(edbox(k),'string',sprintf('%.2f',cgain(k)));
            set(slide(k+3),'value',cofst(k)+0.5); 
            set(edbox(k+3),'string',sprintf('%.2f',cofst(k)));
        end
        
        if cmode == 0, % RGB
            set(swap,'str','YUV/HSV');
            for k=1:3,
                set(lab(k),'str',labelrgb{k});
                yui(:,:,k) = uint8(cgain(k)*double(xui(:,:,k)) + cofst(k)*256);
            end
            
        elseif cmode == 1, % YUV
            set(swap,'str','HSV/RGB');
            for k=1:3,
                set(lab(k),'str',labelyuv{k});
                if k==1, yyuv(:,:,k) = max(min(xyuv(:,:,k)*cgain(k)+cofst(k),1),0);
                else yyuv(:,:,k) = max(min(xyuv(:,:,k)*cgain(k)+cofst(k),0.5),-0.5); 
                end
            end
            yui = uint8(255*yuv2rgb(yyuv));
            
        else % HSV
            set(swap,'str','RGB/YUV');
            for k=1:3,
                set(lab(k),'str',labelhsv{k});
                if k==1, yhsv(:,:,k) = mod(xhsv(:,:,k)*cgain(k)+cofst(k),1);
                else yhsv(:,:,k) = max(min(xhsv(:,:,k)*cgain(k)+cofst(k),1),0); 
                end
            end
            yui = uint8(255*hsv2rgb(yhsv));
        end
        
        update_y;
        figure(2);
        
end
    
