% ph_filter.m
% Routine called by 'Filter' menu item in photo editor.
% Applies lowpass and higpass filters to an image.
%
% Nick Kingsbury, Cambridge University, 2006.

switch mode
    
    case 'Init'  
        % Set up figure window for commands
        figure(2);
        set(gcf,'position',[fig2pos  450  100]);
        set(gcf,'numbertitle','off','name','Filter Image');
        
        % Initialise filter parameters for breadths and G0.
        sc = [10 10 1]; % Scale factors for breadths and G0.
        if exist('filpar')~=1, filpar = [2 2 1]'; end
        
        % Buttons for different filter parameters.
        label = {'Lowpass breadth:','Highpass breadth:','Highpass DC gain:'};
        for k = 1:3,
            ypos = 70 - 20*k; xpos = 10;
            slide(k) = uicontrol(gcf,'style','slider','sliderstep',[1 10]/100,...
                'pos',[xpos+100 ypos 120 20],'call','mode=''Slider''; ph_filter');
            uicontrol(gcf,'style','text','str',label{k},'pos',[xpos ypos 100 20]);
            edbox(k) = uicontrol(gcf,'style','edit','pos',[xpos+220 ypos 60 20],...
                'call','mode=''Edit box''; ph_filter');
        end
        uicontrol(gcf,'style','text','str','Adjust Filters','pos',[100 70 120 16]);
        
        % Other buttons: Denoise, Enhance, Revert and Close.
        lowpass = uicontrol(gcf,'pos',[310 70 130 20],...
            'call','mode=''Lowpass''; ph_filter');
        highpass = uicontrol(gcf,'pos',[310 40 130 20],...
            'call','mode=''Highpass''; ph_filter');
        revert = uicontrol(gcf,'str','Revert','pos',[310 10 60 20],...
            'call','mode=''Revert''; ph_filter');
        closebtn = uicontrol(gcf,'str','Close','pos',[380 10 60 20],...
            'call','mode=''Close''; ph_filter');
        
        % Initialise variables and set yui = xui.
        y = double(xui);
        iter_Lo = 0;
        iter_Hi = 0;
        set(lowpass,'str',sprintf('Lowpass filter, iter %d',iter_Lo));
        set(highpass,'str',sprintf('Highpass filter, iter %d',iter_Hi));
        for k=1:3, 
            set(slide(k),'value',filpar(k)/sc(k));
            set(edbox(k),'string',sprintf('%.2f',filpar(k)));
        end;
        yui = uint8(y + 0.5); 
        update_y; 
        figure(2);
        
    case 'Slider'
        for k=1:3, 
            filpar(k) = sc(k)*get(slide(k),'value');
            set(edbox(k),'string',sprintf('%.2f',filpar(k)));
        end;
        
    case 'Edit box'
        for k=1:3, 
            filpar(k) = sscanf(get(edbox(k),'string'),'%f');
            set(slide(k),'value',filpar(k)/sc(k));
            set(edbox(k),'string',sprintf('%.2f',filpar(k)));
        end;
        
    case 'Lowpass'
        iter_Lo = iter_Lo + 1;
        set(lowpass,'str',sprintf('Lowpass filter, iter %d',iter_Lo));
        y = im_lowpass(y,filpar(1));
        yui=uint8(y+0.5); 
        update_y; 
        figure(2);
        
    case 'Highpass'
        iter_Hi = iter_Hi + 1;
        set(highpass,'str',sprintf('Highpass filter, iter %d',iter_Hi));
        G0 = filpar(3);
        y = (1+G0)*y - im_lowpass(y,filpar(2)) + (1-G0)*128;
        yui=uint8(y+0.5); 
        update_y; 
        figure(2);
        
    case 'Revert'
        y = double(xui);
        yui=uint8(y); 
        iter_Lo = 0;
        iter_Hi = 0;
        update_y; 
        figure(2);
        set(lowpass,'str',sprintf('Lowpass filter, iter %d',iter_Lo));
        set(highpass,'str',sprintf('Highpass filter, iter %d',iter_Hi));
        
    case 'Close'
        close(2); 
        newbefore = 1; 
        showimages;

    end
    
