% ph_morph.m
%
% Script called by 'Morph' menu item in photo editor.
%
% Nick Kingsbury, Cambridge University, November 2005.

% Set up figure window for Rotate commands
figure(2);
set(gcf,'position',[400  624  360  100]);
set(gcf,'numbertitle','off','name','Morph Image');

% Buttons for multiples of 90 deg.
label2 = strvcat('New','Add','Delete','Play','Load','Save');
for u = 1:6,
   ui2(u) = uicontrol(gcf,'str',label2(u,:),'pos',[50*u-30 60 50 20]);
end
uicontrol(gcf,'style','text','str','','pos',[30 80 240 16]);

% Other buttons: slider, edit box, and accept box.
theta = 0;
slide = uicontrol(gcf,'style','slider','value',theta/360+0.5,'sliderstep',[1 10]/360,'pos',[10 10 120 20]);
uicontrol(gcf,'style','text','str','Adjust Rotation','pos',[10 30 120 16]);
edbox = uicontrol(gcf,'style','edit','string',sprintf('%.2f',theta),'pos',[150 10 60 20]);
uicontrol(gcf,'style','text','str','Rotation (deg)','pos',[140 30 80 16]);
accpt = uicontrol(gcf,'str','Close','pos',[230 10 60 20]);

% Main call-back strings, to get control points and interpolate and play
% morph sequences.
pr0 = 'Click Start button';
pr1 = 'Place cross on morph start point';
pr2 = 'Place cross on morph end point';
pr3 = 'Place circle at radius from start point';
pr4 = 'Click button to morph back and forth';

reset = 'newbefore=1; showimages; figure(2);';

getpts = ['set(contrbutton,''str'',''Terminate morph'',''call'',reset);'...
    'while 1,'...
      'set(promptbox,''str'',pr1); c0 = ginputnk(1,''crosshair'');'...
      'if isempty(c0) | any(c0<0), break; end;'...
      'hold on; plot(c0(1),c0(2),''c+''); hold off;'...
      'set(promptbox,''str'',pr2); c1 = ginputnk(1,''cross'');'...
      'if isempty(c1) | any(c1<0), break; end;'...
      'hold on; plot(c1(1),c1(2),''cx''); hold off;'...
      'set(promptbox,''str'',pr3); c2 = ginputnk(1,''circle'');'...
      'if isempty(c2) | any(c2<0), break; end;'...
      'rad = sqrt(sum((c2-c0).^2)); cp = [cp; c0 c1 rad];'...
      '[yui,xshift] = im_morph(xui,xshift,cp(end,:)); update_y;'...
    'end;' reset];

interpviews = ['figure(1); set(yhandle,''Erasemode'',''none'');'...
    'yu = uint8(zeros([size(yui) 10]));'...
    'for k=1:10, yui = im_morph(xui,((k-1)/9)*xshift);'...
      'yu(:,:,:,k) = yui; set(yhandle,''Cdata'',yui); drawnow;'...
    'end; set(promptbox,''str'',pr4);'...
    'set(contrbutton,''str'',''Play again'',''call'',dispviews);'];

dispviews = ['figure(1); set(yhandle,''Erasemode'',''none'');'...
    'for k=1:10, yui = yu(:,:,:,k*dk+5.5*(1-dk));'...
      'set(yhandle,''Cdata'',yui); pause(0.05); end; dk = -dk;'];

addpts = ['update_y; set(promptbox,''str'',pr0);'...
    'set(contrbutton,''str'',''Start morph'',''call'',getpts);'];

% Define callback functions for each button to set theta and perform rotation.
set(ui2(1),'call',['cp=[]; xshift=0; figure(1); yui = xui;' addpts]);
set(ui2(2),'call',['figure(1); [yui,xshift] = im_morph(xui,0,cp);' addpts]);
set(ui2(3),'call','cp=cp(max(end-1,1),:); [yui,xshift] = im_morph(xui,0,cp); update_y;');
set(ui2(4),'call',[interpviews 'dk=1;' dispviews]);
set(ui2(5),'call',' ');
set(ui2(6),'call',' ');
set(slide,'call',['theta=(get(slide,''value'')-0.5)*360;']);
set(edbox,'call',['theta=sscanf(get(edbox,''string''),''%f'');']);
set(accpt,'call','close(gcf); showimages;');



