function y = rgb2hsv(x)

%RGB2HSV Convert red-green-blue colors to hue-saturation-value.
% x and y must be 3-D colour image arrays, covering the range 0 to 1.
%
% Simplified from the standard matlab function by 
% Nick Kingsbury, Cambridge University, 2006.

% Get colour slices
r = x(:,:,1); g = x(:,:,2); b = x(:,:,3); 
siz = size(r);
r = r(:); g = g(:); b = b(:);

% Compute v and unnormalised s.
v = max(max(r,g),b);
s = zeros(size(v));
h = zeros(size(v));
s = (v - min(min(r,g),b));

% Compute h.
z = ~s; % z is used to set h=0 when s=0.
s = s + z;
k = find(r == v);
h(k) = (g(k) - b(k))./s(k);
k = find(g == v);
h(k) = 2 + (b(k) - r(k))./s(k);
k = find(b == v);
h(k) = 4 + (r(k) - g(k))./s(k);
h = h/6;
k = find(h < 0);
h(k) = h(k) + 1; % Adjust negative h to be between 0 and 1. 
h=(~z).*h; % Set h=0 if s=0.

% Normalise s with v, unless v=0, when we make s=0 also.
k = find(v);
s(k) = (~z(k)).*s(k)./v(k);
k = find(~v);
s(k) = 0;

% Assemble h in correct 3D format.
h = reshape(h,siz);
s = reshape(s,siz);
v = reshape(v,siz);
y = cat(3,h,s,v);
return
