% showimages.m
%
% Script to display the 'Before' and 'After' images and their histograms.
%
% Nick Kingsbury, Cambridge University, 2006.

figure(1)

% Display the 'Before' image, if it has changed.
if newbefore,
    h1 = subplot('Position',[0.03 0.35 0.45 0.55]);
    xhandle = image(xui); 
    axis image;
    title('Before','FontSize',14);
    drawnow;
    % Set the default prompt text and control button function.
    set(promptbox,'str','Choose ''Photo-edit'' menu-function');
    set(contrbutton,'str','Close editor','call','ph_savefile; close all');
end

% Display the 'After' image.
h2 = subplot('Position',[0.53 0.35 0.45 0.55]);
yhandle = image(yui);
axis image;
title('After','FontSize',14);
drawnow;

% Define bar colours for the histograms (red, dark green, blue).
barcolour = [0.9 0 0; 0 0.7 0; 0 0 1];

% Display the 'Before' histogram, if it has changed.
if newbefore,
    h3 = subplot('Position',[0.03 0.05 0.45 0.2]);
    sx = size(xui);
    % Reshape image to 3 columns of RGB values.
    xh = reshape(xui,prod(sx(1:2)),3); 
    [nb,hout] = hist(double(xh),4.5:10:254.5); % Calculate histogram.
    ha = bar(hout,nb); % Plot histogram.
    % Set bar colours and make edge lines the same colour.
    for k=1:3, 
      set(ha(k),'FaceColor',barcolour(k,:),'EdgeColor',barcolour(k,:)); 
    end
    title('Histogram of Before','FontSize',14)
    set(gca,'XLim',[0 260]); % Set x-axis limits.
    drawnow;
end

% Display the 'After' histogram.
h4 = subplot('Position',[0.53 0.05 0.45 0.2]);
sy = size(yui);
yh = reshape(yui,prod(sy(1:2)),3);
[nb,hout] = hist(double(yh),4.5:10:254.5);
hb = bar(hout,nb);
for k=1:3, 
    set(hb(k),'FaceColor',barcolour(k,:),'EdgeColor',barcolour(k,:)); 
end
title('Histogram of After','FontSize',14);
set(gca,'XLim',[0 260]);
drawnow;

% Enable zooming of all the images. 
zoom on;

% Display command figure (2), if one exists.
figs = findobj('Type','figure'); % Find current figures.
if any(figs==2), figure(2); end % Display figure 2 as command figure.
if any(figs>2), close(figs(find(figs>2))); end % Close any extra figs.

