% stephighpass.m
%
% Highpass step responses.
%
% Nick Kingsbury, Cambridge University, 2006.

pos1 = [0.05 0.6 0.43 0.28]; % Use subplot so text is a reasonable size.
dp = 0.4; % Vertical displacement between plots.

% pdf of 2-D Normal distr with mean 0 and variance 1.
sig = sqrt(1);
xmin = -20;
xmax = 20;
dx = 1;
x = [xmin:dx:xmax]';
sx = size(x,1);
sx2 = (sx-1)/2;
y = [zeros(sx2,1); 0.5; ones(sx2,1)];
yL = colfilter(y,gaussian(5));

setfig(1)
subplot('position',pos1);
plot(x,y,'-b','Linewidth',2);
axis([xmin xmax -0.5 1.5]);
grid on
title('(a) Step function','Fontsize',14)

subplot('position',pos1 + [0 -dp 0 0]);
plot(x,yL,'-b','Linewidth',2);
axis([xmin xmax -0.5 1.5]);
grid on
title('(b) Lowpass filtered step','Fontsize',14)

subplot('position',pos1 + [0.5 0 0 0]);
plot(x,2*y - yL,'-b','Linewidth',2);
axis([xmin xmax -0.5 1.5]);
grid on
title('(c) Highpass filtered step, unit DC gain','Fontsize',14)

subplot('position',pos1 + [0.5 -dp 0 0]);
plot(x,1*(y - yL),'-b','Linewidth',2);
axis([xmin xmax -1 1]);
grid on
title('(d) Highpass filtered step, zero DC gain','Fontsize',14)

print -depsc 'stephighpass'
